@@ -1,12 +1,12 @@
-from __future__ import unicode_literals
 from django.conf import settings
 from django.dispatch import receiver
 from django.test.signals import setting_changed
 
 DEFAULT_CONFIG = {
     'js': [],
+    'css': {},
     'init_template': None,
-    'settings': {}
+    'settings': {},
 }
 CONFIG = DEFAULT_CONFIG.copy()
 CONFIG.update(getattr(settings, 'DJRICHTEXTFIELD_CONFIG', {}))
